@@ -254,9 +254,11 @@ Answer:"""
 
 
 class PlaceboTree(Recipe):
+    do_not_test = True
+
     async def run(self, *, paper: Paper):
         arms_recipe = ExperimentArms(mode=self.mode)
-        arms, arm_descriptions = await arms_recipe.run(paper=paper)
+        arms, arm_descriptions = await arms_recipe.run(paper=paper)  # type: ignore[call-arg]
 
         placebo_class, placebo_description_draft = await self.classify_placebo(
             paper, arms, arm_descriptions
