@@ -1,3 +1,5 @@
+from fvalues import F
+
 from ice.recipe import recipe
 from ice.recipes.primer.subquestions import ask_subquestions
 from ice.utils import map_async
@@ -11,17 +13,19 @@ Subs = list[tuple[Question, Answer]]
 def render_background(subs: Subs) -> str:
     if not subs:
         return ""
-    subs_text = "\n\n".join(f"Q: {q}\nA: {a}" for (q, a) in subs)
-    return f"Here is relevant background information:\n\n{subs_text}\n\n"
+    subs_text = F("\n\n").join(F(f"Q: {q}\nA: {a}") for (q, a) in subs)
+    return F(f"Here is relevant background information:\n\n{subs_text}\n\n")
 
 
 def make_qa_prompt(question: str, subs: Subs) -> str:
     background_text = render_background(subs)
-    return f"""{background_text}Answer the following question, using the background information above where helpful:
+    return F(
+        f"""{background_text}Answer the following question, using the background information above where helpful:
 
 Question: "{question}"
 Answer: "
-""".strip()
+"""
+    ).strip()
 
 
 async def get_subs(question: str, depth: int) -> Subs:
