@@ -1,20 +1,24 @@
+from fvalues import F
+
 from ice.recipe import recipe
 
 
 def make_computation_choice_prompt(question: str) -> str:
-    return f"""You've been asked to answer the question "{question}".
+    return F(
+        f"""You've been asked to answer the question "{question}".
 
 You have access to a Python interpreter.
 
 Enter an expression that will help you answer the question.
 >>>"""
+    )
 
 
 def eval_python(expression: str) -> str:
     try:
         result = eval(expression)
     except Exception as e:
-        result = f"Error: {e}"
+        result = F(f"Error: {e}")
     return str(result)
 
 
