@@ -1,3 +1,7 @@
+from collections.abc import Sequence
+
+from fvalues import F
+
 from ice.paper import Paper
 from ice.paper import Paragraph
 from ice.recipe import recipe
@@ -6,10 +10,12 @@ from ice.utils import map_async
 
 
 def make_classification_prompt(paragraph: Paragraph, question: str) -> str:
-    return f"""Here is a paragraph from a research paper: "{paragraph}"
+    return F(
+        f"""Here is a paragraph from a research paper: "{paragraph}"
 
 Question: Does this paragraph answer the question '{question}'? Say Yes or No.
 Answer:"""
+    )
 
 
 async def classify_paragraph(paragraph: Paragraph, question: str) -> float:
@@ -33,12 +39,12 @@ async def get_relevant_paragraphs(
 
 
 async def answer_for_paper(
-    paper: Paper, question: str = "What was the study population?"
-):
-    relevant_paragraphs = await get_relevant_paragraphs(paper, question)
-    relevant_str = "\n\n".join(str(p) for p in relevant_paragraphs)
+    paper: Paper, question: str = "What was the study population?", top_n: int = 3
+) -> tuple[str, Sequence[str]]:
+    relevant_paragraphs = await get_relevant_paragraphs(paper, question, top_n=top_n)
+    relevant_str = F("\n\n").join(str(p) for p in relevant_paragraphs)
     response = await answer(context=relevant_str, question=question)
-    return response
+    return response, [str(p) for p in relevant_paragraphs]
 
 
 recipe.main(answer_for_paper)
