@@ -1,17 +1,21 @@
 import httpx
 
+from fvalues import F
+
 from ice.recipe import recipe
 
 
 def make_qa_prompt(context: str, question: str) -> str:
-    return f"""
+    return F(
+        f"""
 Background text: "{context}"
 
 Answer the following question about the background text above:
 
 Question: "{question}"
 Answer: "
-""".strip()
+"""
+    ).strip()
 
 
 async def search(query: str = "Who is the president of the United States?") -> dict:
