@@ -1,13 +1,17 @@
+from fvalues import F
+
 from ice.recipe import recipe
 
 
 def make_verification_prompt(question: str, answer: str) -> str:
-    return f"""Consider this question: "{question}"
+    return F(
+        f"""Consider this question: "{question}"
 
 Potential answer: "{answer}"
 
 Q: Is the potential answer above correct? Say "A: Yes" or "A: No".
 A:"""
+    )
 
 
 async def verify_answer(question: str, answer: str) -> float:
