@@ -1,4 +1,6 @@
 import logging
+import os
+import signal
 
 from pathlib import Path
 
@@ -8,7 +10,7 @@ from starlette.responses import FileResponse
 from starlette.responses import PlainTextResponse
 
 from ice.routes import traces
-from ice.trace import trace_dir
+from ice.trace import traces_dir
 
 logger = logging.getLogger(__name__)
 
@@ -17,7 +19,7 @@ dist_dir = Path(__file__).parent / "ui"
 app = FastAPI()
 app.include_router(traces.router)
 app.mount(
-    "/api/traces/", StaticFiles(directory=trace_dir), name="static"
+    "/api/traces/", StaticFiles(directory=traces_dir), name="static"
 )  # see comment on get_trace
 
 try:
@@ -28,6 +30,20 @@ except RuntimeError:
     )
 
 
+PING_RESPONSE = "ought-ice says pong"
+
+
+@app.get("/ping")
+async def ping():
+    return PlainTextResponse(PING_RESPONSE)
+
+
+@app.post("/stop")
+async def stop():
+    # Note that this doesn't work properly when the server runs with --reload
+    os.kill(os.getpid(), signal.SIGKILL)
+
+
 @app.get("/{_full_path:path}")
 async def catch_all(_full_path: str):
     path = dist_dir / "index.html"
