@@ -15,9 +15,17 @@ class Settings(BaseSettings):
     OPENAI_API_KEY: str = ""
     OPENAI_ORG_ID: str = ""
     OUGHT_INFERENCE_API_KEY: str = ""
-    OUGHT_INFERENCE_URL: AnyHttpUrl = "https://inference.elicit.org"
-    GOLD_STANDARDS_CSV_PATH: str = "gold_standards/gold_standards.csv"
+    OUGHT_INFERENCE_URL: AnyHttpUrl = "https://prod.elicit.org"
+    ELICIT_AUTH_TOKEN: str = ""
+    GOLD_STANDARDS_CSV_PATH: Path = (
+        Path(__file__).parent.parent / "gold_standards/gold_standards.csv"
+    )
     GS_QUOTE_FOUND_THRESHOLD: float = 0.75
+    OUGHT_ICE_HOST: str = "0.0.0.0"
+    OUGHT_ICE_PORT: int = 8935
+    OUGHT_ICE_AUTO_SERVER: bool = True
+    OUGHT_ICE_AUTO_BROWSER: bool = True
+    PAPER_DIR: Path = Path(__file__).parent.parent / "papers"
 
 
 OUGHT_ICE_DIR = Path(environ.get("OUGHT_ICE_DIR", Path.home() / ".ought-ice"))
@@ -29,3 +37,7 @@ settings = Settings(
 
 CACHE_DIR = OUGHT_ICE_DIR / "cache"
 CACHE_DIR.mkdir(parents=True, exist_ok=True)
+
+
+def server_url() -> str:
+    return f"http://{settings.OUGHT_ICE_HOST}:{settings.OUGHT_ICE_PORT}"
