@@ -9,6 +9,7 @@ from faker import Faker
 from ice.paper import Paper
 from ice.recipe import FunctionBasedRecipe
 from ice.recipe import recipe
+from ice.trace import enable_trace
 
 Faker.seed(0)
 fake = Faker()
@@ -16,6 +17,7 @@ fake = Faker()
 
 root_dir = Path(__file__).parent.parent
 
+recipe.all_recipes = []
 primer_recipes_dir = root_dir / "ice" / "recipes" / "primer"
 for path in primer_recipes_dir.glob("**/*.py"):
     relative_path = path.relative_to(primer_recipes_dir)
@@ -39,4 +41,5 @@ async def test_all_primer_recipes(main: FunctionBasedRecipe):
         else:
             raise ValueError(f"Cannot handle parameter {p}")
         kwargs[p.name] = value
+    enable_trace()
     await main(**kwargs)
