@@ -1,8 +1,7 @@
 import { Button, Collapse, Skeleton, useToast } from "@chakra-ui/react";
 import classNames from "classnames";
 import produce from "immer";
-import { isEmpty, isString, last, omit, set } from "lodash";
-import { CaretDown, CaretRight, ChatCenteredDots } from "phosphor-react";
+import { isEmpty, last, memoize, set } from "lodash";
 import {
   createContext,
   Dispatch,
@@ -23,6 +22,15 @@ import Spinner from "./Spinner";
 import { recipes } from "/helpers/recipes";
 import * as COLORS from "/styles/colors.json";
 import { useParams } from "react-router";
+import { isHighlighted, Toolbar } from "/components/TracePage/Toolbar";
+import { CallFunction, CallName, getFormattedName } from "/components/TracePage/CallName";
+import { CallIconButton } from "./CallIconButton";
+import {
+  FlattenedFStringPart,
+  flattenFString,
+  FString,
+  RawFStringPart,
+} from "/components/TracePage/FString";
 
 const elicitStyle = {
   "hljs-keyword": { color: COLORS.indigo[600] }, // use primary color for keywords
@@ -45,20 +53,44 @@ const getContentLength = async (url: string) => {
   return isNaN(length) ? 0 : length;
 };
 
-interface CallInfo {
-  parent: string;
-  start: number;
-  name: string;
-  doc: string;
-  args: Record<string, unknown>;
-  source?: string;
-  children?: Record<string, CallInfo>;
-  records?: Record<string, CallInfo>;
-  result?: unknown;
-  end?: number;
+// Detailed values of a function call to show in the sidebar.
+type InputOutputContentProps = {
+  // Call arguments, i.e. inputs
+  args: BlockAddress<Record<string, unknown>>;
+  // The full return value
+  result?: BlockAddress<unknown>;
+  // Arbitrary optional additional data
+  records?: Record<string, BlockAddress<unknown>>;
+};
+
+export interface CallInfo extends InputOutputContentProps {
+  parent: string; // outer call ID
+  start: number; // start time
+  name: string; // function name
+  cls?: string; // class name for methods
+  shortArgs: string; // short representation of args
+  shortResult?: string[]; // short representation of return value
+  children?: Calls; // nested calls
+  fields?: Record<string, string>; // short arbitrary fields associated with the call
+  func: BlockAddress<FuncBlock>; // long info about the function itself
+  end?: number; // end time
+  totalTokens?: number;
 }
 
-type Calls = Record<string, CallInfo>;
+interface FuncBlock {
+  doc: string;
+  source?: string;
+}
+
+export type Calls = Record<string, CallInfo>;
+
+// Mapping from block number (identifies the filename) to a list of lines.
+// Each line is a JSON string.
+type Blocks = Record<number, string[]>;
+
+// Describes where to load a value of type T from Blocks.
+// Represents [block number, line number].
+type BlockAddress<T> = [number, number];
 
 const MODEL_CALL_NAMES = [
   "relevance",
@@ -73,23 +105,50 @@ const TreeContext = createContext<{
   traceId: string;
   rootId: string;
   calls: Calls;
+  getBlockValue: <T>(block: BlockAddress<T>) => T | undefined;
   selectedId: string | undefined;
   setSelectedId: Dispatch<SetStateAction<string | undefined>>;
   getExpanded: (id: string) => boolean;
   setExpanded: (id: string, expanded: boolean) => void;
+  setExpandedById: Dispatch<SetStateAction<Record<string, boolean>>>;
   getFocussed: (id: string) => boolean;
+  highlightedFunction: CallFunction | undefined;
+  setHighlightedFunction: Dispatch<SetStateAction<CallFunction | undefined>>;
+  othersHidden: boolean;
+  setOthersHidden: Dispatch<SetStateAction<boolean>>;
+  isVisible: (id: string) => boolean;
 } | null>(null);
 
 const applyUpdates = (calls: Calls, updates: Record<string, unknown>) =>
-  Object.entries(updates).forEach(([path, value]) => set(calls, path, value));
+  Object.entries(updates).forEach(([path, value]) => {
+    set(calls, path, value);
+    if (path.endsWith(".fields.davinci_equivalent_tokens")) {
+      const tokens = Number(value);
+      if (isNaN(tokens)) return;
+      const callId = path.split(".")[0];
+      let call = calls[callId];
+      while (call) {
+        call.totalTokens = (call.totalTokens ?? 0) + tokens;
+        call = calls[call.parent];
+      }
+    }
+  });
+
+const urlPrefix = (traceId: string) => {
+  const base = recipes[traceId] ? "https://oughtinc.github.io/static" : "/api";
+  return `${base}/traces/${traceId}`;
+};
 
 const TreeProvider = ({ traceId, children }: { traceId: string; children: ReactNode }) => {
   const traceOffsetRef = useRef(0);
   const [calls, setCalls] = useState<Calls>({});
+  const [blocks, setBlocks] = useState<Blocks>({});
   const [selectedId, setSelectedId] = useState<string>();
   const [rootId, setRootId] = useState<string>("");
   const [expandedById, setExpandedById] = useState<Record<string, boolean>>({});
   const [autoselected, setAutoselected] = useState(false);
+  const [highlightedFunction, setHighlightedFunction] = useState<CallFunction>();
+  const [othersHidden, setOthersHidden] = useState(false);
 
   useEffect(() => {
     if (!autoselected) {
@@ -106,21 +165,21 @@ const TreeProvider = ({ traceId, children }: { traceId: string; children: ReactN
     }
   }, [autoselected, calls, traceId]);
 
+  const isMounted = useRef(true);
+
   useEffect(() => {
-    let mounted = true;
     let timeoutId: ReturnType<typeof setTimeout>;
 
     const poll = async () => {
       let delay = 1_000;
       try {
-        const urlPrefix = recipes[traceId] ? "https://oughtinc.github.io/static" : "/api";
-        const url = `${urlPrefix}/traces/${traceId}.jsonl`;
+        const url = `${urlPrefix(traceId)}/trace.jsonl`;
         const offset = traceOffsetRef.current;
         const contentLength = await getContentLength(url);
         if (offset >= contentLength) return;
 
         const initialOffset = 1e6;
-        const subsequentOffset = 1e7;
+        const subsequentOffset = 1e9;
         const limit = Math.min(
           offset + (offset === 0 ? initialOffset : subsequentOffset),
           contentLength,
@@ -133,7 +192,7 @@ const TreeProvider = ({ traceId, children }: { traceId: string; children: ReactN
         const { status } = response;
         if (status !== 206) throw new Error(`Unexpected status: ${status}`);
         const text = await response.text();
-        if (!mounted) return;
+        if (!isMounted.current) return;
 
         const end = text.lastIndexOf("\n") + 1;
         traceOffsetRef.current += end;
@@ -148,7 +207,7 @@ const TreeProvider = ({ traceId, children }: { traceId: string; children: ReactN
       } catch (e) {
         console.warn("fetch failed", e);
       } finally {
-        if (mounted) {
+        if (isMounted.current) {
           timeoutId = setTimeout(poll, delay);
         }
       }
@@ -157,7 +216,7 @@ const TreeProvider = ({ traceId, children }: { traceId: string; children: ReactN
     poll();
 
     return () => {
-      mounted = false;
+      isMounted.current = false;
       clearTimeout(timeoutId);
     };
   }, [traceId]);
@@ -180,20 +239,98 @@ const TreeProvider = ({ traceId, children }: { traceId: string; children: ReactN
     return (id: string) => focussedIds.includes(id);
   }, [selectedId, calls, rootId]);
 
+  // Placeholders for this render cycle to avoid fetching the same block multiple times.
+  // This gets updated during rendering, which is why we don't use state.
+  const blockRequests = useRef<Set<number>>(new Set());
+
+  function getBlockValue<T>(blockAddress: BlockAddress<T>): T | undefined {
+    const [blockNumber, blockLineno] = blockAddress;
+    const block = blocks[blockNumber];
+    if (block) {
+      if (blockLineno < block.length) {
+        return JSON.parse(block[blockLineno]);
+      }
+      return undefined; // wait for the other lines
+    }
+
+    if (blockRequests.current.has(blockNumber)) {
+      // This block has already been requested.
+      return undefined;
+    }
+    blockRequests.current.add(blockNumber);
+
+    const url = `${urlPrefix(traceId)}/block_${blockNumber}.jsonl`;
+    const fetchBlock = async (start: number) => {
+      // Note that the 999999999 is needed because our get_file implementation
+      // requires both ends of the range to be specified.
+      const response = await fetch(url, { headers: { Range: `bytes=${start}-999999999` } });
+      const text = await response.text();
+
+      if (!isMounted.current) return;
+
+      start += text.length;
+      const lines = text.split("\n");
+      // Remove the last line. Normally it's empty, i.e. text should end in a newline.
+      // This also handles lines being incomplete,
+      // in which case `start` is moved to the beginning of that line.
+      start -= lines.pop()!.length;
+
+      if (last(lines) === "end") {
+        lines.pop();
+      } else {
+        // This block is incomplete, schedule polling for the rest.
+        setTimeout(() => fetchBlock(start), 1_000);
+      }
+
+      if (lines.length) {
+        setBlocks((blocks: Blocks) => ({
+          ...blocks,
+          [blockNumber]: [...(blocks[blockNumber] ?? []), ...lines],
+        }));
+      }
+    };
+    fetchBlock(0);
+    return undefined;
+  }
+
+  const isVisible = useMemo(() => {
+    if (!othersHidden || !highlightedFunction) return () => true;
+
+    const checkParents = memoize((id: string): boolean => {
+      const call = calls[id];
+      return call && (isHighlighted(call, highlightedFunction) || checkParents(call.parent));
+    });
+    const checkChildren = memoize((id: string): boolean => {
+      const call = calls[id];
+      return (
+        call &&
+        (isHighlighted(call, highlightedFunction) ||
+          Object.keys(call.children || {}).some(checkChildren))
+      );
+    });
+    return (id: string) => checkParents(id) || checkChildren(id);
+  }, [othersHidden, highlightedFunction, calls]);
+
   return (
     <TreeContext.Provider
       value={{
         traceId,
         calls,
+        getBlockValue,
         rootId,
         selectedId,
         setSelectedId,
         getExpanded: (id: string) => expandedById[id] ?? false,
         setExpanded: (id: string, expanded: boolean) => {
-          if (id !== rootId && !isModelCall(calls[id]))
-            setExpandedById(current => ({ ...current, [id]: expanded }));
+          if (id !== rootId) setExpandedById(current => ({ ...current, [id]: expanded }));
         },
+        setExpandedById,
+        highlightedFunction,
+        setHighlightedFunction,
         getFocussed,
+        othersHidden,
+        setOthersHidden,
+        isVisible,
       }}
     >
       {children}
@@ -201,7 +338,7 @@ const TreeProvider = ({ traceId, children }: { traceId: string; children: ReactN
   );
 };
 
-const useTreeContext = () => {
+export const useTreeContext = () => {
   const context = useContext(TreeContext);
   if (!context) throw new Error("useTreeContext must be used within a TreeProvider");
   return context;
@@ -217,19 +354,9 @@ const useCallInfo = (id: string) => {
   };
 };
 
-type SelectedCallInfo = {
-  parent: string;
-  start: number;
-  name: string;
-  doc: string;
-  args: Record<string, unknown>;
-  source?: string;
-  children?: Record<string, CallInfo>;
-  records?: Record<string, CallInfo>;
-  result?: unknown;
-  end?: number;
+interface SelectedCallInfo extends CallInfo {
   id: string;
-};
+}
 
 const useSelectedCallInfo = (): SelectedCallInfo | undefined => {
   const { calls, selectedId } = useTreeContext();
@@ -266,47 +393,43 @@ const useLinks = () => {
   return { getParent, getChildren, getPrior: getSiblingAt(-1), getNext: getSiblingAt(1) };
 };
 
-const isModelCall = ({ name, args }: { name: string; args: Record<string, unknown> }) =>
-  MODEL_CALL_NAMES.includes(name) &&
-  (args as any).self?.class_name &&
-  (args as any).self.class_name.includes("Agent");
-
-const getFormattedName = (snakeCasedName: string) => {
-  const spacedName = snakeCasedName.replace(/_/g, " ");
-  const capitalizedAndSpacedName = spacedName[0].toUpperCase() + spacedName.slice(1);
-  return capitalizedAndSpacedName;
-};
-
-const CallName = ({ className, id }: { className?: string; id: string }) => {
-  const { name, args } = useCallInfo(id);
-  const recipeClassName = (args as any).self?.class_name;
-  const displayName =
-    (name === "execute" || name === "run") && recipeClassName ? recipeClassName : name;
-  const modelCall = isModelCall({ name, args });
-  return (
-    <div className="flex items-center gap-1">
-      {recipeClassName && recipeClassName !== displayName ? (
-        <span className={classNames(className, "text-gray-500")}>
-          {getFormattedName(recipeClassName)}:
-        </span>
-      ) : undefined}
-      <span className={className}>{getFormattedName(displayName)}</span>
-    </div>
-  );
-};
+const isModelCall = ({ cls, name }: CallInfo) =>
+  MODEL_CALL_NAMES.includes(name) && !!cls?.includes("Agent");
 
 function lineAnchorId(id: string) {
   return `line-anchor-${id}`;
 }
 
+const COST_USD_PER_DAVINCI_TOKEN = 0.02 / 1000;
+const CURRENCY_FORMATTER = new Intl.NumberFormat("en-US", {
+  style: "currency",
+  currency: "USD",
+});
+
 const Call = ({ id, refreshArcherArrows }: { id: string; refreshArcherArrows: () => void }) => {
-  const { name, args, children = {}, result, select, selected, focussed } = useCallInfo(id);
-  const { selectedId } = useTreeContext();
+  const callInfo = useCallInfo(id);
+  const { selectedId, highlightedFunction, isVisible } = useTreeContext();
   const { getParent } = useLinks();
-  const childIds = Object.keys(children);
   const { expanded, setExpanded } = useExpanded(id);
 
-  const modelCall = isModelCall({ name, args });
+  if (!isVisible(id)) return null;
+
+  const {
+    children = {},
+    select,
+    selected,
+    focussed,
+    shortArgs,
+    shortResult,
+    totalTokens,
+    cls,
+    name,
+  } = callInfo;
+
+  const childIds = Object.keys(children);
+  const cost = totalTokens && totalTokens * COST_USD_PER_DAVINCI_TOKEN;
+
+  const modelCall = isModelCall(callInfo);
   const isSiblingWithSelected = selectedId && getParent(id) === getParent(selectedId);
 
   return (
@@ -321,6 +444,7 @@ const Call = ({ id, refreshArcherArrows }: { id: string; refreshArcherArrows: ()
         })}
       >
         <Button
+          as="div"
           className={classNames(
             "justify-start text-start items-start h-fit min-w-[300px] p-1.5 !shadow-none",
           )}
@@ -330,6 +454,12 @@ const Call = ({ id, refreshArcherArrows }: { id: string; refreshArcherArrows: ()
             ev.stopPropagation();
           }}
           isActive={selected}
+          {...(isHighlighted(callInfo, highlightedFunction)
+            ? {
+                borderColor: "yellow.500",
+                borderWidth: "5px",
+              }
+            : {})}
         >
           <ArcherElement
             id={lineAnchorId(id)}
@@ -343,46 +473,30 @@ const Call = ({ id, refreshArcherArrows }: { id: string; refreshArcherArrows: ()
                 : []
             }
           >
-            {childIds.length > 0 ? (
-              <Button
-                aria-label={expanded ? "Collapse" : "Expand"}
-                className={classNames(
-                  "rounded-full p-1 h-fit mr-2 !shadow-none hover:bg-slate-200 w-12",
-                )}
-                leftIcon={modelCall ? undefined : expanded ? <CaretDown /> : <CaretRight />}
-                size="md"
-                isActive={expanded}
-                variant="outline"
-                onClick={event => {
-                  setExpanded(!expanded);
-                  // Theres a hard to debug layout thing here, where sometimes
-                  // the arrows don't redraw properly when nodes are expanded.
-                  setTimeout(() => refreshArcherArrows(), 50);
-                }}
-              >
-                <span className={"mr-1"}>{modelCall ? <ChatCenteredDots /> : childIds.length}</span>
-              </Button>
-            ) : (
-              <Button
-                className={classNames(
-                  "rounded-full p-1 h-fit mr-2 !shadow-none hover:bg-slate-200 w-12",
-                )}
-                size="md"
-                variant="outline"
-              >
-                <span>𝑓</span>
-              </Button>
-            )}
+            <CallIconButton
+              expanded={expanded}
+              onChange={expanded => {
+                setExpanded(!expanded);
+                // Theres a hard to debug layout thing here, where sometimes
+                // the arrows don't redraw properly when nodes are expanded.
+                setTimeout(() => refreshArcherArrows(), 50);
+              }}
+              childCount={childIds.length}
+              isModelCall={modelCall}
+            />
           </ArcherElement>
           <div className="mx-2">
-            <CallName className="text-base text-slate-700" id={id} />
+            <CallName className="text-base text-slate-700" cls={cls} name={name} />
             <div className="text-sm text-gray-600 flex items-center">
-              <span className="text-indigo-600" title={JSON.stringify(getStrings(args), null, 4)}>
-                {getShortString(getStrings(args)?.[0] || "()")}
-              </span>
+              <span className="text-indigo-600">{shortArgs}</span>
               <span className="px-2">→</span>
-              {result === undefined ? <Spinner size="small" /> : <ResultComponent value={result} />}
+              {shortResult === undefined ? (
+                <Spinner size="small" />
+              ) : (
+                <ResultComponent value={shortResult} />
+              )}
             </div>
+            {cost && CURRENCY_FORMATTER.format(cost)}
           </div>
         </Button>
       </div>
@@ -416,57 +530,15 @@ const CallChildren = ({
   );
 };
 
-const isObjectLike = (value: unknown): value is object =>
-  value !== null && typeof value === "object";
-
-const isArrayWithString = (value: unknown): value is unknown[] =>
-  Array.isArray(value) && isString(value[0]);
-
-const getFirstDescendant = (value: unknown): unknown => {
-  if (isObjectLike(value) && !isArrayWithString(value)) {
-    return getFirstDescendant(Object.values(value)[0]);
-  }
-  if (isArrayWithString(value)) {
-    return value.filter(isString);
-  }
-  return value;
-};
-
-const getStrings = (value: any): string[] => {
-  if (isObjectLike(value)) {
-    if ("value" in value) {
-      value = (value as any).value;
-    } else {
-      if ("self" in value) {
-        value = omit(value, "self");
-      }
-      if ("record" in value) {
-        value = omit(value, "record");
-      }
-    }
-  }
-
-  const result = getFirstDescendant(value);
-
-  return Array.isArray(result) ? result : [`${result ?? "()"}`];
-};
-
-const getShortString = (string: any, maxLength: number = 35): string => {
-  return string.length > maxLength ? string.slice(0, maxLength).trim() + "..." : string;
-};
-
-const ResultComponent = ({ value }: { value: any }): JSX.Element => {
-  const strings = getStrings(value);
-
+const ResultComponent = ({ value }: { value: string[] }): JSX.Element => {
   return (
     <>
-      {strings.map((string, idx) => (
+      {value.map((string, idx) => (
         <div
           className="px-[4px] py-[2px] mx-[3px] bg-lightBlue-50 text-lightBlue-600 rounded-4"
           key={idx}
-          title={string}
         >
-          {getShortString(string)}
+          {string}
         </div>
       ))}
     </>
@@ -476,7 +548,7 @@ const ResultComponent = ({ value }: { value: any }): JSX.Element => {
 type JsonChild =
   | { type: "array"; values: unknown[] }
   | { type: "object"; values: [string, unknown][] }
-  | { type: "value"; value: unknown };
+  | { type: "value"; value: unknown; fstring?: FlattenedFStringPart[] };
 
 const getStructuralType = (data: unknown) => {
   if (typeof data === "object" && data && !Array.isArray(data)) return "object";
@@ -496,7 +568,15 @@ const DetailRenderer = ({ data, root }: { data: unknown; root?: boolean }) => {
     if (typeof data === "object" && data) {
       // Array or Object
       if (Array.isArray(data)) return { type: "array", values: data };
-      else return { type: "object", values: Object.entries(data) };
+      if ("__fstring__" in data) {
+        const parts = data.__fstring__ as RawFStringPart[];
+        const flattenedParts = flattenFString(parts);
+        const value = flattenedParts
+          .map(part => (typeof part === "string" ? part : part.value))
+          .join("");
+        return { type: "value", value, fstring: flattenedParts };
+      }
+      return { type: "object", values: Object.entries(data) };
     }
     return { type: "value", value: data };
   }, [data]);
@@ -534,7 +614,7 @@ const DetailRenderer = ({ data, root }: { data: unknown; root?: boolean }) => {
         toast({ title: "Copied to clipboard", duration: 1000 });
       }}
     >
-      {value}
+      {view.fstring ? <FString parts={view.fstring} /> : value}
     </span>
   ) : (
     <span className="text-gray-600">empty</span>
@@ -567,22 +647,23 @@ type DetailPaneContentProps = {
 type Tab = "io" | "src";
 
 const DetailPaneContent = ({ info }: DetailPaneContentProps) => {
-  const { id, doc } = info;
+  const { func, cls, name } = info;
   const [tab, setTab] = useState<Tab>("io"); // io for inputs and outputs, src for source
+  const { getBlockValue } = useTreeContext();
 
   return (
     <div className="flex-1 p-6">
-      <TabHeader id={id} doc={doc} />
+      <TabHeader cls={cls} name={name} doc={getBlockValue(func)?.doc} />
       <TabBar tab={tab} setTab={setTab} />
       <TabContent tab={tab} info={info} />
     </div>
   );
 };
 
-const TabHeader = ({ id, doc }: { id: string; doc: string }) => (
+const TabHeader = ({ cls, name, doc }: { cls?: string; name: string; doc?: string }) => (
   <div className="mb-4">
     <h3 className="text-lg font-semibold text-gray-800">
-      <CallName id={id} />
+      <CallName cls={cls} name={name} />
     </h3>
     <p className="text-gray-600 text-sm whitespace-pre-line">{doc}</p>
   </div>
@@ -618,25 +699,20 @@ const TabButton = ({ label, value, tab, setTab }: TabButtonProps) => (
 );
 
 const TabContent = ({ tab, info }: { tab: Tab; info: CallInfo }) => {
-  const { args, records = {}, result, source } = info;
+  const { func, args, records, result } = info;
+  const { getBlockValue } = useTreeContext();
 
   return (
     <div className="space-y-4 mt-4">
       {tab === "io" ? (
         <InputOutputContent args={args} records={records} result={result} />
       ) : (
-        <SourceContent source={source} />
+        <SourceContent source={getBlockValue(func)?.source} />
       )}
     </div>
   );
 };
 
-type InputOutputContentProps = {
-  args: any;
-  records: any;
-  result: any;
-};
-
 const excludeMetadata = (source: Record<string, unknown> | undefined) => {
   if (source === undefined) return undefined;
   return Object.fromEntries(
@@ -644,13 +720,23 @@ const excludeMetadata = (source: Record<string, unknown> | undefined) => {
   );
 };
 
-const InputOutputContent = ({ args, records, result }: InputOutputContentProps) => (
-  <>
-    <Json name="Inputs" value={excludeMetadata(args)} />
-    {!isEmpty(records) && <Json name="Records" value={Object.values(records)} />}
-    <Json name="Outputs" value={result} />
-  </>
-);
+const InputOutputContent = ({ args, records, result }: InputOutputContentProps) => {
+  const { getBlockValue } = useTreeContext();
+  return (
+    <>
+      <Json name="Inputs" value={excludeMetadata(getBlockValue(args))} />
+      {!isEmpty(records) && (
+        <Json
+          name="Records"
+          value={Object.values(records)
+            .map(getBlockValue)
+            .filter(v => v)}
+        />
+      )}
+      <Json name="Outputs" value={result && getBlockValue(result)} />
+    </>
+  );
+};
 
 type SourceContentProps = {
   source: string | undefined;
@@ -704,6 +790,7 @@ const stripIndent = (source: string): string => {
 const Trace = ({ traceId }: { traceId: string }) => {
   const { selectedId, rootId, setSelectedId, getExpanded, setExpanded } = useTreeContext();
   const { getParent, getChildren, getPrior, getNext } = useLinks();
+  // const params = useParams()
 
   const maybeSetSelectedId = useCallback(
     (update: (id: string) => string | undefined) => {
@@ -793,6 +880,7 @@ const Trace = ({ traceId }: { traceId: string }) => {
     <div className="flex flex-col h-full min-h-screen max-h-screen">
       <div className="flex divide-x divide-gray-100 flex-1 overflow-clip">
         <div className="flex-1 p-6 overflow-y-auto flex-shrink-0">
+          <Toolbar />
           <ArcherContainer
             ref={archerContainerRef}
             noCurves
@@ -817,6 +905,7 @@ const Trace = ({ traceId }: { traceId: string }) => {
           <DetailPane />
         </div>
       </div>
+      {/* {Object.keys(params)} */}
     </div>
   );
 };
